script <- '
set.seed(1234)
nrep <- 1000
n1 <- subSampleSize
n2 <- 120 - n1
v1 <- 1
v2 <- subVariance
result <- rep(NA, nrep)
for(i in 1:nrep) {
	y1 <- rnorm(n1, 0, sqrt(v1))
	y2 <- rnorm(n2, 0, sqrt(v2))
	y <- c(y1, y2)
	g <- c(rep(1, n1), rep(2, n2))
	dat <- data.frame(g = g, y = y)
	out <- t.test(y ~ g, data = dat, var.equal = TRUE)
	result[i] <- out[["p.value"]]
}
write.csv(result, file="outputsubNum.csv")
'

# Create combination of the sample-size condition and the variance condition. 
# The 'expand.grid' function is used to create all possible combination 
# of all conditions.
n1 <- c(20, 40, 60, 80, 100)
v2 <- c(1, 3, 10)
condition <- expand.grid(n1, v2)

# The R script template will be substituted by the condition values from 
# each combination. Then, the substituted template will be written in sim*.R
for(i in 1:nrow(condition)) {
	temp <- gsub("subSampleSize", condition[i, 1], script)
	temp <- gsub("subVariance", condition[i, 2], temp)
	temp <- gsub("subNum", i, temp)
	write(temp, paste("sim", i, ".R", sep=""))
}
